@@ -1,4 +1,10 @@
-# Extends: survival    #########################################################
+
+# replacement for stats:::logLik.logLik
+logLik.logLik <- 
+function (object, ...) {
+	if (!missing(...))  warning("extra arguments discarded")
+	object
+}
 
 # logLik for survival::coxph model
 # https://stat.ethz.ch/pipermail/r-help/2006-December/122118.html
